@@ -35,7 +35,9 @@ class YQLApi(object):
         if self.community:            
             final_url += '&env='+urllib.quote_plus('store://datatables.org/alltableswithkeys')
         
-        response=urllib.urlopen(final_url)
+        req = urllib2.Request(final_url)
+        response = urllib2.urlopen(req)
+
         api_data=simplejson.load(response)
         result = api_data.get('query',{}).get('results',{})
 
